<?php
session_start();
include('config.php');

$user_id = isset($_SESSION['dealer_id']) ? $_SESSION['dealer_id'] : null;

if ($user_id === null) {
    echo json_encode(['status' => 'error', 'message' => 'User not found.']);
    exit;
}

// Verify that the user exists in the dealers_accounts table
$stmt = $pdo->prepare("SELECT COUNT(*) FROM dealers_accounts WHERE dealer_id = :user_id");
$stmt->execute([':user_id' => $user_id]);
$userExists = $stmt->fetchColumn();

if (!$userExists) {
    echo json_encode(['status' => 'error', 'message' => 'Invalid user.']);
    exit;
}

try {
    // Start transaction
    $pdo->beginTransaction();

    // Calculate total amount
    error_log("Calculating total amount for user_id: $user_id");
    $stmt = $pdo->prepare("SELECT SUM(products.product_price * cart_details.quantity) AS total_amount
                           FROM cart_details
                           JOIN products ON cart_details.product_id = products.product_id
                           WHERE cart_details.user_id = :user_id");
    $stmt->execute([':user_id' => $user_id]);
    $totalAmount = $stmt->fetchColumn();
    error_log("Total amount calculated: " . json_encode($totalAmount));

    if ($totalAmount === false || $totalAmount === null) {
        // Fetch the query result for debugging
        $stmt = $pdo->prepare("SELECT products.product_price, cart_details.quantity
                               FROM cart_details
                               JOIN products ON cart_details.product_id = products.product_id
                               WHERE cart_details.user_id = :user_id");
        $stmt->execute([':user_id' => $user_id]);
        $cartItems = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Log the cart items for debugging
        error_log("Cart items: " . json_encode($cartItems));

        throw new Exception("Could not calculate total amount.");
    }

    // Insert order into the orders table
    error_log("Inserting order for user_id: $user_id with total_amount: $totalAmount");
    $stmt = $pdo->prepare("INSERT INTO orders (user_id, total_amount, status, created_at) VALUES (:user_id, :total_amount, 'Pending', NOW())");
    $stmt->execute([':user_id' => $user_id, ':total_amount' => $totalAmount]);
    $order_id = $pdo->lastInsertId();
    error_log("Order inserted with order_id: $order_id");

    // Insert cart items into the order_items table
    error_log("Inserting cart items into order_items table for order_id: $order_id");
    $stmt = $pdo->prepare("INSERT INTO order_items (order_id, product_id, quantity, price)
                           SELECT :order_id, cart_details.product_id, cart_details.quantity, products.product_price
                           FROM cart_details
                           JOIN products ON cart_details.product_id = products.product_id
                           WHERE cart_details.user_id = :user_id");
    $stmt->execute([':order_id' => $order_id, ':user_id' => $user_id]);

    // Clear the cart
    error_log("Clearing the cart for user_id: $user_id");
    $stmt = $pdo->prepare("DELETE FROM cart_details WHERE user_id = :user_id");
    $stmt->execute([':user_id' => $user_id]);

    // Commit transaction
    $pdo->commit();
    error_log("Transaction committed successfully for user_id: $user_id");

    echo json_encode(['status' => 'success']);
} catch (Exception $e) {
    // Rollback transaction in case of error
    $pdo->rollBack();
    error_log("Error: " . $e->getMessage());
    echo json_encode([
        'status' => 'error',
        'message' => 'Failed to process the order. Please try again.',
        'error' => $e->getMessage()
    ]);
}
?>
